-- ========================================================================= --
--                                                                           --
-- Licensed Materials - Property of IBM                                      --
--                                                                           --
-- "Restricted Materials of IBM"                                             --
--                                                                           --
-- 5724-S45                                                                  --
--                                                                           --
-- (C) Copyright IBM Corp. 1997, 2009                                        --
--                                                                           --
-- IBM Tivoli Network Manager IP Edition                                     --
--                                                                           --
-- ========================================================================= --

--
-- This script will update existing NCIM core databases to include all changes
-- made since the GA release of version 3.7.
--
-- USAGE: 
-- mysql <ncim DB name> -u <mysql username> -p<mysql password> [-P <port>] < updateNetCoolCoreDb.sql
-- eg: mysql ncim -u ncim -pncim -P 3506 < updateNetCoolCoreDb.sql
--
-- NOTE: It is vital that all commands executed by this file be valid when 
-- executed against either the GA release or against later patched versions.
--

-- =========================================================================
-- insertConnection function 
--
-- This is usually created automatically by ncp_model as part of the fix
-- for IZ45326. Automatic creation can fail if MySQL DB permissions have 
-- been restricted, in which case this function should be created as the
-- admin user.
-- =========================================================================

DROP FUNCTION IF EXISTS insertConnection;

DELIMITER //
CREATE FUNCTION insertConnection
    (
        newAEndEntityId    INTEGER,
        newZEndEntityId    INTEGER,
        newUnidirectional  INTEGER,
        topologyEntityId   INTEGER
    )
    RETURNS INTEGER
    DETERMINISTIC
BEGIN

    DECLARE cachedConnectionId INTEGER;

    --
    -- First task is to see if we already have the connection, and
    -- to create it if not
    --
    SELECT  c.connectionId
    INTO    cachedConnectionId
    FROM    connects c
    WHERE   c.aEndEntityId = newAEndEntityId
    AND     c.zEndEntityId = newZEndEntityId
    AND     c.unidirectional = newUnidirectional;

    IF cachedConnectionId IS NULL THEN
        INSERT INTO connects (aEndEntityId, zEndEntityId, unidirectional)
        VALUES (newAEndEntityId, newZEndEntityId, newUnidirectional);

        SET cachedConnectionId = LAST_INSERT_ID();
    END IF;

    IF topologyEntityId > 0 THEN
        --
        -- Then reference that connection in the topologyLinks
        --
        INSERT INTO topologyLinks
        (
            entityId,
            connectionId
        )
        VALUES
        (
            topologyEntityId,
            cachedConnectionId
        );
    END IF;

    RETURN cachedConnectionId;

END;
//
DELIMITER ;

-- =========================================================================
-- End of File
-- =========================================================================
